@@ -246,10 +246,12 @@ class QueryParameter:
         raise ValueError(f"Could not parse Query parameter from {obj}")
 
     def __str__(self) -> str:
-        return f"QueryParameter(" \
-               f"name: {self.key}, " \
-               f"value: {self.value}, " \
-               f"type: {self.type.value})"
+        return (
+            f"QueryParameter("
+            f"name: {self.key}, "
+            f"value: {self.value}, "
+            f"type: {self.type.value})"
+        )
 
 
 @dataclass
@@ -328,8 +330,8 @@ class DuneQuery:
     def from_environment(
         cls,
         raw_sql: str,
-        description: str,
         network: Network,
+        description: str = "",
         parameters: Optional[list[QueryParameter]] = None,
         name: Optional[str] = None,
     ) -> DuneQuery:
@@ -388,7 +390,7 @@ class DuneQuery:
                 "name",
                 "description",
                 "query",
-                "private_to_group_id",
+                "is_private",
                 "is_temp",
                 "is_archived",
                 "created_at",
@@ -454,7 +456,7 @@ class DuneQuery:
                   name
                   description
                   query
-                  private_to_group_id
+                  is_private
                   is_temp
                   is_archived
                   created_at
